==> jc-1.4.0.tar.gz: java/rmi/server/ServerCloneException.h <==
// public class java.rmi.server.ServerCloneException

// class file dependencies
// @dep_class d59353b5e031d754 java_lang_CloneNotSupportedException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 9798874377169d29 java_rmi_server_ServerCloneException

// header file dependencies
// @dep_header java_lang_CloneNotSupportedException

#include "java/lang/CloneNotSupportedException.h"

#ifndef _JC_java_rmi_server_ServerCloneException_H_
#define _JC_java_rmi_server_ServerCloneException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_rmi_server_ServerCloneException$sub_refs	_jc_java_rmi_server_ServerCloneException$sub_refs;
typedef struct _jc_java_rmi_server_ServerCloneException$sub_nonrefs	_jc_java_rmi_server_ServerCloneException$sub_nonrefs;
typedef struct _jc_java_rmi_server_ServerCloneException$refs	_jc_java_rmi_server_ServerCloneException$refs;
typedef struct _jc_java_rmi_server_ServerCloneException$nonrefs	_jc_java_rmi_server_ServerCloneException$nonrefs;
typedef struct _jc_java_rmi_server_ServerCloneException$object	_jc_java_rmi_server_ServerCloneException$object;

typedef struct _jc_java_rmi_server_ServerCloneException$fields_struct	_jc_java_rmi_server_ServerCloneException$fields_struct;
typedef const struct _jc_java_rmi_server_ServerCloneException$vmethods	_jc_java_rmi_server_ServerCloneException$vmethods;
typedef const struct _jc_java_rmi_server_ServerCloneException$vtable	_jc_java_rmi_server_ServerCloneException$vtable;
typedef const struct _jc_java_rmi_server_ServerCloneException$vtype	_jc_java_rmi_server_ServerCloneException$vtype;

// Class fields structure
struct _jc_java_rmi_server_ServerCloneException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_server_ServerCloneException$fields_struct _jc_java_rmi_server_ServerCloneException$class_fields;

// Constructors
extern void _jc_java_rmi_server_ServerCloneException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_rmi_server_ServerCloneException$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_rmi_server_ServerCloneException$method$_init$d27a3a3f2a4ade11(_jc_env *, struct _jc_java_rmi_server_ServerCloneException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Exception$object *);

// Virtual methods
extern struct _jc_java_lang_Throwable$object *_jc_java_rmi_server_ServerCloneException$method$getCause$d5a96efc8523817a(_jc_env *, struct _jc_java_rmi_server_ServerCloneException$object *);
extern struct _jc_java_lang_String$object *_jc_java_rmi_server_ServerCloneException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_java_rmi_server_ServerCloneException$object *);

// Virtual method descriptors
extern _jc_method _jc_java_rmi_server_ServerCloneException$method_info$getCause$d5a96efc8523817a;
extern _jc_method _jc_java_rmi_server_ServerCloneException$method_info$getMessage$13aaf240efc902b1;

// Virtual methods structure
struct _jc_java_rmi_server_ServerCloneException$vmethods {
	struct _jc_java_lang_Throwable$object	*(*getCause$d5a96efc8523817a)(_jc_env *, struct _jc_java_rmi_server_ServerCloneException$object *);
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_java_rmi_server_ServerCloneException$object *);
};

// Vtable
struct _jc_java_rmi_server_ServerCloneException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_CloneNotSupportedException$vmethods	java_lang_CloneNotSupportedException;
	_jc_java_rmi_server_ServerCloneException$vmethods	java_rmi_server_ServerCloneException;
};

// Vtype
struct _jc_java_rmi_server_ServerCloneException$vtype {
	_jc_type			type;
	_jc_java_rmi_server_ServerCloneException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_server_ServerCloneException$sub_refs {
	struct _jc_java_lang_Exception$object	*detail;
};

// Reference instance fields (object)
struct _jc_java_rmi_server_ServerCloneException$refs {
    _jc_java_rmi_server_ServerCloneException$sub_refs	java_rmi_server_ServerCloneException;
    _jc_java_lang_CloneNotSupportedException$sub_refs	java_lang_CloneNotSupportedException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_server_ServerCloneException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_server_ServerCloneException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_CloneNotSupportedException$sub_nonrefs	java_lang_CloneNotSupportedException;
    _jc_java_rmi_server_ServerCloneException$sub_nonrefs	java_rmi_server_ServerCloneException;
};

// Object instance structure
struct _jc_java_rmi_server_ServerCloneException$object {
	_jc_java_rmi_server_ServerCloneException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_server_ServerCloneException$vtype	*vtype;
	_jc_java_rmi_server_ServerCloneException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_server_ServerCloneException$vtype _jc_java_rmi_server_ServerCloneException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_server_ServerCloneException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_server_ServerCloneException$class_object;

#endif	/* _JC_java_rmi_server_ServerCloneException_H_ */

==> jc-1.4.6.tar.gz: java/rmi/server/ServerCloneException.h <==
// public class java.rmi.server.ServerCloneException

// class file dependencies
// @dep_class d59353b5e031d754 java_lang_CloneNotSupportedException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 9798874377169d29 java_rmi_server_ServerCloneException

// header file dependencies
// @dep_header java_lang_CloneNotSupportedException

#include "java/lang/CloneNotSupportedException.h"

#ifndef _JC_java_rmi_server_ServerCloneException_H_
#define _JC_java_rmi_server_ServerCloneException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_rmi_server_ServerCloneException$sub_refs	_jc_java_rmi_server_ServerCloneException$sub_refs;
typedef struct _jc_java_rmi_server_ServerCloneException$sub_nonrefs	_jc_java_rmi_server_ServerCloneException$sub_nonrefs;
typedef struct _jc_java_rmi_server_ServerCloneException$refs	_jc_java_rmi_server_ServerCloneException$refs;
typedef struct _jc_java_rmi_server_ServerCloneException$nonrefs	_jc_java_rmi_server_ServerCloneException$nonrefs;
typedef struct _jc_java_rmi_server_ServerCloneException$object	_jc_java_rmi_server_ServerCloneException$object;

typedef struct _jc_java_rmi_server_ServerCloneException$fields_struct	_jc_java_rmi_server_ServerCloneException$fields_struct;
typedef const struct _jc_java_rmi_server_ServerCloneException$vmethods	_jc_java_rmi_server_ServerCloneException$vmethods;
typedef const struct _jc_java_rmi_server_ServerCloneException$vtable	_jc_java_rmi_server_ServerCloneException$vtable;
typedef const struct _jc_java_rmi_server_ServerCloneException$vtype	_jc_java_rmi_server_ServerCloneException$vtype;

// Class fields structure
struct _jc_java_rmi_server_ServerCloneException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_server_ServerCloneException$fields_struct _jc_java_rmi_server_ServerCloneException$class_fields;

// Constructors
extern void _jc_java_rmi_server_ServerCloneException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_rmi_server_ServerCloneException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_server_ServerCloneException$method$_init$d27a3a3f2a4ade11(_jc_env *, struct _jc_java_rmi_server_ServerCloneException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Exception$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Throwable$object *_jc_java_rmi_server_ServerCloneException$method$getCause$d5a96efc8523817a(_jc_env *, struct _jc_java_rmi_server_ServerCloneException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_rmi_server_ServerCloneException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_java_rmi_server_ServerCloneException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_rmi_server_ServerCloneException$method_info$getCause$d5a96efc8523817a;
extern _jc_method _jc_java_rmi_server_ServerCloneException$method_info$getMessage$13aaf240efc902b1;

// Virtual methods structure
struct _jc_java_rmi_server_ServerCloneException$vmethods {
	struct _jc_java_lang_Throwable$object	*(*getCause$d5a96efc8523817a)(_jc_env *, struct _jc_java_rmi_server_ServerCloneException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_java_rmi_server_ServerCloneException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_rmi_server_ServerCloneException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_CloneNotSupportedException$vmethods	java_lang_CloneNotSupportedException;
	_jc_java_rmi_server_ServerCloneException$vmethods	java_rmi_server_ServerCloneException;
};

// Vtype
struct _jc_java_rmi_server_ServerCloneException$vtype {
	_jc_type			type;
	_jc_java_rmi_server_ServerCloneException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_server_ServerCloneException$sub_refs {
	struct _jc_java_lang_Exception$object	*detail;
};

// Reference instance fields (object)
struct _jc_java_rmi_server_ServerCloneException$refs {
    _jc_java_rmi_server_ServerCloneException$sub_refs	java_rmi_server_ServerCloneException;
    _jc_java_lang_CloneNotSupportedException$sub_refs	java_lang_CloneNotSupportedException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_server_ServerCloneException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_server_ServerCloneException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_CloneNotSupportedException$sub_nonrefs	java_lang_CloneNotSupportedException;
    _jc_java_rmi_server_ServerCloneException$sub_nonrefs	java_rmi_server_ServerCloneException;
};

// Object instance structure
struct _jc_java_rmi_server_ServerCloneException$object {
	_jc_java_rmi_server_ServerCloneException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_server_ServerCloneException$vtype	*vtype;
	_jc_java_rmi_server_ServerCloneException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_server_ServerCloneException$vtype _jc_java_rmi_server_ServerCloneException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_server_ServerCloneException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_server_ServerCloneException$class_object;

#endif	/* _JC_java_rmi_server_ServerCloneException_H_ */
